#!/usr/bin/perl -w
#
# makephotoalbum - make photo album from PhotoProc .sh scripts or directly
# from JPGs using exif orientation information.
#
# This file is part of PhotoPNMTools,
# Release $Name: rel-1-3-0 $,
# File rev. $Id: makephotoalbum.pl,v 1.4 2003/03/13 01:25:56 schooten Exp $.
#
# Copyright (c) 2002, 2003 by B.W. van Schooten. All rights reserved.
# This software is distributed under the Perl Artistic License.
# No warranty. See file 'artistic.license' for more details.
#
# boris@13thmonkey.org
# www.13thmonkey.org/~boris/photopnmtools/

if ($#ARGV < 6) {
	print "\nUsage:\n";
	print "makephotoalbum.pl  <xsize> <ysize> <thumbxsize> <thumbysize>\n";
	print "                   <albumname> <photosperpage> ";
	print "[ list of .sh files and/or .jpg files ]\n\n";
	exit 0;
}

$xsize = shift @ARGV;
$ysize = shift @ARGV;
$thumbxsize = shift @ARGV;
$thumbysize = shift @ARGV;
$albumname = shift @ARGV;
$photosperpage = shift @ARGV;


@files = @ARGV;

$nrphotos = $#files + 1;

$nrpages = int($nrphotos / $photosperpage);

if ($nrpages*$photosperpage < $nrphotos) { $nrpages++; }


$pagenr = 1;

$photonr = 0;

foreach $f (@files) {
	if ($photonr == 0) {
		# new file
		open HTML, ">album-$pagenr.html";
		print HTML "<html><head><title>$albumname ($pagenr/$nrpages)</title>";
		print HTML "</head><body><center>\n";
		print HTML "<h1>$albumname ($pagenr/$nrpages)</h1>\n";
		print HTML "<h2>\n";
		if ($pagenr > 1) {
			$prevpage = $pagenr - 1;
			print HTML "<a href=\"album-$prevpage.html\"".
						">&lt;&lt;&lt; previous</a>";
		}
		if ($pagenr > 1 && $pagenr < $nrpages) {
			print HTML "&nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;";
		}
		if ($pagenr < $nrpages) {
			$nextpage = $pagenr + 1;
			print HTML "<a href=\"album-$nextpage.html\"".
						">next &gt;&gt;&gt;</a>";
		}
		print HTML "\n</h2><P>\n";
	}
	$basename = $f;
	$basename =~ s/^.*\///; # chop path
	$rotcmd = "";
	if ($f=~/\.jpg$/ or $f=~/\.JPG$/ or $f=~/\.jpeg$/ or $f=~/\.JPEG$/ ) {
		$basename =~ s/\.....$//; # chop .jpeg
		$basename =~ s/\....$//; # chop .jpg
		system "getexifrotation.pl $f";
		$exit_value  = $? >> 8;
		if ($exit_value == 1) {
			$rotcmd = " | pnmflip -r270 ";
		} elsif ($exit_value == 2) {
			$rotcmd = " | pnmflip -r90 ";
		}
		system "jpegtopnm $f $rotcmd > $basename-fudged.ppm";
	} else { # we assume it's a shell file
		$basename =~ s/\.sh$//;
		$basename =~ s/-fudge$//;
		system "sh $f";
	}
	system "pnmresample -x $xsize -y $ysize -b <$basename-fudged.ppm | " . 
		 "pnmconvolve -s 14 -u -b 0.04 -i 2 | " .
		 "ppmtojpeg --sample 1x1 --quality 85 >$basename-sm.jpg";
	system "pnmresample -x $thumbxsize -y $thumbysize -b " .
				"<$basename-fudged.ppm|". 
		 "pnmconvolve -s 8 -u -b 0.04 -i 1 | " .
		 "ppmtojpeg --quality 70 >$basename-th.jpg";
	system "rm $basename-fudged.ppm";
	open PHOTOFRAME, ">$basename-sm.html";
	print PHOTOFRAME "<html><head><title>$basename</title></head>\n";
	print PHOTOFRAME "<body bgcolor=\"black\"><center>\n";
	print PHOTOFRAME "<BR><BR><img src=\"$basename-sm.jpg\">\n";
	print PHOTOFRAME "</center></body></html>\n";
	close PHOTOFRAME;
	print HTML "<a href=\"$basename-sm.html\">"
				."<img src=\"$basename-th.jpg\"></a>\n";
	$photonr++;
	if ($photonr == $photosperpage || $photonr >= $nrphotos  ) {
		print HTML "</body></html>\n";
		close HTML;
		$pagenr++;
		$photonr = 0;
	}
}


